fnss.topologies.randmodels.waxman_1_topology — FNSS 0.7.0 documentation

# fnss.topologies.randmodels.waxman_1_topology

`waxman_1_topology`(n, alpha=0.4, beta=0.1, L=1.0, distance_unit='Km', seed=None)

  Return a Waxman-1 random topology.

  The Waxman-1 random topology models assigns link between nodes with probability

  where the distance d is chosen randomly in [0,L].

  Parameters: | n : int Number of nodes alpha : float Model parameter chosen in (0,1] (higher alpha increases link density) beta : float Model parameter chosen in (0,1] (higher beta increases difference between density of short and long links) L : float Maximum distance between nodes. seed : int, optional Seed for random number generator (default=None).
  Returns: | G : Topology

  Notes

  Each node of G has the attributes latitude and longitude. These attributes are not expressed in degrees but in distance_unit.

  Each edge of G has the attribute length, which is also expressed in distance_unit.

  References

  [R4545] | B. M. Waxman, Routing of multipoint connections. IEEE J. Select. Areas Commun. 6(9),(1988) 1617-1622.